@@ -15,24 +15,26 @@ if(run.inspect.tests){
   inspect_apsimx(i, src.dir = ex.dir, node = "Clock")        
   inspect_apsimx(i, src.dir = ex.dir, node = "Weather")        
   inspect_apsimx(i, src.dir = ex.dir, node = "Soil")
-  inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "Water")
+  inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "Physical")
   inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "SoilWater")
+  inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "SoilWater", parm = "SummerDate")
+  inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "SoilWater", parm = "SummerCona")
   inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "Organic")
   inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "InitialWater")
   inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "Chemical")
-  inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "InitialN")
+  inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "InitialN") 
   inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "CERESSoilTemperature")
   inspect_apsimx(i, src.dir = ex.dir, node = "SurfaceOrganicMatter")
   inspect_apsimx(i, src.dir = ex.dir, node = "MicroClimate")
   inspect_apsimx(i, src.dir = ex.dir, node = "Crop")
   inspect_apsimx(i, src.dir = ex.dir, node = "Manager")
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("SowingFertiliser",NA))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("Sow on a fixed date",NA))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("Sow on a fixed date",1))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("Sow on a fixed date",2))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("Sow on a fixed date",3))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("Sow on a fixed date",5))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("Sow on a fixed date",6))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("SowingFertiliser", NA))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("Sow on a fixed date", NA))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("Sow on a fixed date", 1))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("Sow on a fixed date", 2))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("Sow on a fixed date", 3))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("Sow on a fixed date", 5))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list("Sow on a fixed date", 6))
 
   ## Maize
   i <- "Maize.apsimx"
@@ -49,15 +51,17 @@ if(run.inspect.tests){
   inspect_apsimx(i, src.dir = ex.dir, node = "MicroClimate")
   inspect_apsimx(i, src.dir = ex.dir, node = "Crop")
   inspect_apsimx(i, src.dir = ex.dir, node = "Manager")
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule',NA))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingFertiliser',NA))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule', NA))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingFertiliser', NA))
   
   ## Oats
   i <- "Oats"
   inspect_apsimx(i, src.dir = ex.dir, node = "Clock")        
   inspect_apsimx(i, src.dir = ex.dir, node = "Weather")        
   inspect_apsimx(i, src.dir = ex.dir, node = "Soil")
+  inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "Water")
   inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "SoilWater")
+  inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "SoilWater", parm = "SummerDate")
   inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "Organic")
   inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "InitialWater")
   inspect_apsimx(i, src.dir = ex.dir, node = "Soil", soil.child = "Chemical")
@@ -65,17 +69,17 @@ if(run.inspect.tests){
   inspect_apsimx(i, src.dir = ex.dir, node = "MicroClimate")
   inspect_apsimx(i, src.dir = ex.dir, node = "Crop")
   inspect_apsimx(i, src.dir = ex.dir, node = "Manager")
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingFert',NA))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1',NA))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1',1))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1',2))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1',3))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1',4))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1',5))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1',6))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1',7))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1',8))
-  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1',9))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingFert', NA))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1', NA))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1', 1))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1', 2))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1', 3))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1', 4))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1', 5))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1', 6))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1', 7))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1', 8))
+  inspect_apsimx(i, src.dir = ex.dir, node = "Manager", parm = list('SowingRule1', 9))
 }
 
 run.inspect.print.path.tests <- get(".run.local.tests", envir = apsimx.options)
@@ -221,6 +225,27 @@ if(inspect.replacement.test2){
                              node.subchild = "Photosynthesis",
                              node.subsubchild = "RUE",
                              parm = "FixedValue")
+
+  ## Soybean Cultivars
+  pp <- inspect_apsimx_replacement("MaizeSoybean.apsimx", 
+                                   src.dir = extd.dir, 
+                                   node = "Soybean",
+                                   node.child = "Stephens_MG40",
+                                   parm = "Vegetative",
+                                   print.path = TRUE)
+  
+  if(pp != ".Simulations.Replacements.Soybean.Stephens_MG40.Vegetative") 
+    stop("Error in inspect_apsimx_replacement, MaizeSoybean, Stephens_MG40, Vegetative, print.path")
+
+  pp <- inspect_apsimx_replacement("MaizeSoybean.apsimx", 
+                                   src.dir = extd.dir, 
+                                   node = "Soybean",
+                                   node.child = "Stephens_MG40",
+                                   parm = "EarlyFlowering",
+                                   print.path = TRUE)
+  
+  if(pp != ".Simulations.Replacements.Soybean.Stephens_MG40.EarlyFlowering") 
+    stop("Error in inspect_apsimx_replacement, MaizeSoybean, Stephens_MG40, EarlyFlowering, print.path")
   
   ## WheatRye version
   inspect_apsimx_replacement("WheatRye.apsimx", src.dir = extd.dir,
@@ -232,6 +257,11 @@ if(inspect.replacement.test2){
                              node = "Wheat", node.child = "Cultivars",
                              node.subchild = "USA", node.subsubchild = "Yecora",
                              parm = "MinimumLeafNumber")
+  ## This only works for the first one
+  inspect_apsimx_replacement("WheatRye.apsimx", src.dir = extd.dir,
+                             node = "Wheat", node.child = "Cultivars",
+                             node.subchild = "USA", node.subsubchild = "Yecora",
+                             parm = "Vrn")
                              
 }
  
@@ -268,5 +298,6 @@ if(inspect.replacement.test.parm.path){
                                    node.child = "Leaf",
                                    parm = "Gxmax350",
                                    print.path = TRUE)
+  ## I don't think this one worked quite as expected
   
 }
